diff --git a/ui/src/components/NavigationBar.tsx b/ui/src/components/NavigationBar.tsx
index 96a8b8f..af39992 100644
--- a/ui/src/components/NavigationBar.tsx
+++ b/ui/src/components/NavigationBar.tsx
@@ -33,6 +33,7 @@ import { Link as RouterLink, useLocation } from "react-router-dom";
import { twMerge } from "tailwind-merge";
import { SignOutButton } from "./SignOutButton";
import { ThemeSwitcher } from "./ThemeSwitcher";
+import { TypographyMuted } from "./ui/typography";
type NavLinkItem = {
isActive?: boolean;
@@ -126,14 +127,18 @@ export function UserMenuPopover({ isCollapsed }: { isCollapsed: boolean }) {
-
{user.name}
-
+
+ {user.name}
+
-
+
-
+
+
+
+
diff --git a/ui/src/components/ThemeSwitcher.tsx b/ui/src/components/ThemeSwitcher.tsx
index 990d769..3971dac 100644
--- a/ui/src/components/ThemeSwitcher.tsx
+++ b/ui/src/components/ThemeSwitcher.tsx
@@ -51,7 +51,7 @@ export function ThemeSwitcher({ isCollapsed = false }: { isCollapsed?: boolean }
size="icon-sm"
onClick={() => setTheme("light")}
aria-label="Mode clair"
- className="flex-1"
+ className="flex-1 border"
>
diff --git a/ui/src/components/TabloModal.tsx b/ui/src/components/TabloModal.tsx
index 0bf09ca..d4de551 100644
--- a/ui/src/components/TabloModal.tsx
+++ b/ui/src/components/TabloModal.tsx
@@ -87,10 +87,10 @@ export const TabloModal = ({ tablo, onClose, onEdit }: TabloModalProps) => {
const file = files?.[0];
if (!file) return;
- // Validate file size (2MB limit)
- const maxSize = 2 * 1024 * 1024; // 2MB in bytes
+ // Validate file size (20MB limit)
+ const maxSize = 20 * 1024 * 1024; // 20MB in bytes
if (file.size > maxSize) {
- setError("Le fichier ne peut pas dépasser 2MB");
+ setError("Le fichier ne peut pas dépasser 20MB");
return;
}